==> xl-react-components-0.16.62.tgz: package/tests/e2e/scenario/widget/xl-react-widget-radio-group/xl-react-widget-radio-group-scenario.js <==
import json from 'format-json';
import Navigation from '../../../dsl/common/navigation';
import TestBindings from '../../../dsl/common/test-bindings';
import WidgetRadioGroup from '../../../dsl/component/widget/widget-radio-group';

describe('XL Widget Radio Group Scenario', () => {
    const initialState = [
        {
            color: 'blue',
            label: 'Case 1',
            value: 'Case 1',
            checked: false
        },
        {
            checked: true,
            color: 'yellow',
            label: 'Case 2',
            value: 'Case 2'
        },
        {
            color: 'red',
            label: 'Case 3',
            value: 'Case 3',
            checked: false
        }
    ];

    const firstOptionSelectedState = [
        {
            color: 'blue',
            label: 'Case 1',
            value: 'Case 1',
            checked: true
        },
        {
            checked: false,
            color: 'yellow',
            label: 'Case 2',
            value: 'Case 2'
        },
        {
            color: 'red',
            label: 'Case 3',
            value: 'Case 3',
            checked: false
        }
    ];

    beforeAll(() => Navigation.openWidgetElement('widgetRadioGroup1'));

    it('should have right initial state', () => {
        TestBindings.expectModelToEqual(json.plain(initialState));
        TestBindings.expectPristineToEqual('true');
    });

    it('should not change model if component disabled', () => {
        TestBindings.toggleDisabled();
        WidgetRadioGroup.selectOption(1);
        TestBindings.expectModelToEqual(json.plain(initialState));
        TestBindings.expectPristineToEqual('true');
        TestBindings.toggleDisabled();
    });

    it('should change model and pristinity', () => {
        WidgetRadioGroup.selectOption(1);
        TestBindings.expectModelToEqual(json.plain(firstOptionSelectedState));
        TestBindings.expectPristineToEqual('false');
    });
});

==> xl-react-components-0.21.15.tgz: package/tests/e2e/scenario/widget/xl-react-widget-radio-group/xl-react-widget-radio-group-scenario.js <==
import json from 'format-json';
import Navigation from '../../../dsl/common/navigation';
import TestBindings from '../../../dsl/common/test-bindings';
import WidgetRadioGroup from '../../../dsl/component/widget/widget-radio-group';

describe('XL Widget Radio Group Scenario', () => {
    const initialState = [
        {
            color: 'blue',
            label: 'Case 1',
            value: 'Case 1',
            checked: false
        },
        {
            checked: true,
            color: 'yellow',
            label: 'Case 2',
            value: 'Case 2'
        },
        {
            color: 'red',
            label: 'Case 3',
            value: 'Case 3',
            checked: false
        }
    ];

    const firstOptionSelectedState = [
        {
            color: 'blue',
            label: 'Case 1',
            value: 'Case 1',
            checked: true
        },
        {
            checked: false,
            color: 'yellow',
            label: 'Case 2',
            value: 'Case 2'
        },
        {
            color: 'red',
            label: 'Case 3',
            value: 'Case 3',
            checked: false
        }
    ];

    beforeAll(() => Navigation.openWidgetElement('widgetRadioGroup1'));

    it('should have right initial state', () => {
        TestBindings.expectModelToEqual(json.plain(initialState));
        TestBindings.expectPristineToEqual('true');
    });

    it('should not change model if component disabled', () => {
        TestBindings.toggleDisabled();
        WidgetRadioGroup.selectOption('Case 1');
        TestBindings.expectModelToEqual(json.plain(initialState));
        TestBindings.expectPristineToEqual('true');
        TestBindings.toggleDisabled();
    });

    it('should change model and pristinity', () => {
        WidgetRadioGroup.selectOption('Case 1');
        TestBindings.expectModelToEqual(json.plain(firstOptionSelectedState));
        TestBindings.expectPristineToEqual('false');
    });
});
